## ----librerias,  echo=TRUE, warning=FALSE, message=FALSE----------------------------------------------------------------------------------------------------------
library(tidyverse) # incluye ggplot2
library(gghemes) # nuevas temas para los 
library(ploteadxl) # funciones para importar xlsx
library(janitor) # funciones de limpieza
library(patchwork) #combinar gráficos de ggplot
library(ggExtra)
library(ggtly) #gráficos interactivos # remotes::install_github("plotly/plotly")
library(tibble)
library(skimr) # reseumen numerico
library(modeest)
library(ggrepel) # añadir etiquetas a los gráficos
library(RColorBrewer) #paletas de colores
library(plotly) #graficos interactivos
library(corrplot)
library(ggridges)


## -----------------------------------------------------------------------------------------------------------------------------------------------------------------
datos_pinguinos <- read.csv("data/data_penguins.csv")
head(datos_pinguinos,5)


## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Ejemplo 1
# Listar los primeros 10 obs de la tabla
head(datos_pinguinos, 10)

# Utilizando pipe
# llamamos el tibble de datos
datos_pinguinos |> 
  head(10)


# Ejemplo 2
# Resumen de lso datos 
summary(datos_pinguinos)


# Usando pipe
datos_pinguinos |> 
  summary()


# Ejemplo 3
# Seleccionar las columnas 3 y 5 del tibble datospinguinos
# donde island es igual a Torgersen
datos_pinguinos[datos_pinguinos$ISLAND.=="Torgersen",c(4,5)]


# Utilizando pipe
datos_pinguinos |> 
  filter(ISLAND.=="Torgersen") |> 
  select(bill.lenght,bill.depth)




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

ggplot()



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

ggplot(data=datos_pinguinos)



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

ggplot(data = datos_pinguinos, 
      mapping = aes(x=SPECIES))



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

ggplot(data = datos_pinguinos, 
      mapping = aes(x=SPECIES))+
  geom_bar()



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

#Ejemplo de gráfico de puntos
ggplot(data = datos_pinguinos, 
       mapping = aes(x=bill.lenght, y=bill.depth))+
       geom_point()

# Ejemplo de gráfico de barras una variable
ggplot(data = datos_pinguinos, 
       mapping = aes(x=SPECIES))+
       geom_bar()

# Ejemplo de gráfico de barras dos variables
ggplot(data = datos_pinguinos, 
       mapping = aes(x=factor(ISLAND.), y=bill.lenght))+
       geom_col()




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# data.frame mtcars muestra todas las filas, se indica con head, mostrar solo 25
head(datos_pinguinos,25)


# Verificar Objeto tipo data.frame
class(datos_pinguinos)




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# transformat dataframe a tible 
datos_pinguinos <- as_tibble(datos_pinguinos)

# Verificar Objeto tipo tibble
class(datos_pinguinos)

# tibble imprime solo las primeras 10 
# coloca el tipo de dato sencima del nombre de la variable
head(datos_pinguinos,10)




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Muestra la estructura de los datos y el tipo de datos
datos_pinguinos |> 
  summary()

# La función glimpse es otra forma de mostrar los datos
# sobre todo cuando son muchas variables
# Muestra tambien el tipo de dato por variable
# Permite mostrar la estructura de datos de forma más ordenada
datos_pinguinos |> 
  glimpse()




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Nombre de las variables
datos_pinguinos |> 
  names()

# limpieza y normalización de nombres de las variables con janitor
datos_pinguinos <- janitor::clean_names(datos_pinguinos)

# eliminar primera columna
datos_pinguinos <- datos_pinguinos[,-1]
datos_pinguinos |> 
  names()

# Resumen de datos
datos_pinguinos |> 
  glimpse()







## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

#Verifcar si una variable tiene datos cualitaticos repetidos 
# lo que indica que puede ser una var categorica
table(datos_pinguinos$species)

#resultado
# Adelie Chinstrap    Gentoo 
#  146        68       119 


# Transformar variables de tipo caracter a factor
datos_pinguinos$species <- as.factor(datos_pinguinos$species)
datos_pinguinos$island<- as.factor(datos_pinguinos$island)

datos_pinguinos |> 
  glimpse()



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

datos_pinguinos |> 
  head(10)



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Transformar  a datos tidy
# Para transformar los datos a tidy, se identifican las columnas o variables 
# que se desean unir y convertir en una sola variable
# se coloca el nombre de la nueva variable con names_to
# los datos que contenian las variable male y female pasan a otra variable 
# a través de values_to.

datos_pinguinos_tidy <- datos_pinguinos |> 
                           pivot_longer(c("male":"female"), 
                           names_to = "sex", 
                           values_to = "body_mass_g")

# numero de observaciones generadas 666
nrow(datos_pinguinos_tidy)

datos_pinguinos_tidy |> 
  head(10)





## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# transformar a datos tidy eliminados filas vacias

datos_pinguinos <- datos_pinguinos |> 
                           pivot_longer(c("male":"female"), 
                           names_to = "sex", 
                           values_to = "body_mass_g",
                           values_drop_na = TRUE)

# numero de observaciones generadas 333
nrow(datos_pinguinos)

# Resumend de datos , donde ya no se muestran los datos NA
datos_pinguinos |> 
  head(10)

#transformar la variable sex a factor
datos_pinguinos$sex <- as.factor(datos_pinguinos$sex)

# write.csv(datos_pinguinos, "data/data_penguins_clean.csv")




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Resumen Numérico de la tabla
datos_pinguinos |>  
   skim()



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram()



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Modificar número de bins
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(bins = 15)



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Modificar el color de las lineas
# Bins predeterminados = 30
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(color ="#ffffff", bins = 30)





## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con colores en los bins para identificar 
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(color ="#ffffff" , 
                 fill = "#EF3C49", 
                 bins = 30)





## ----warning=FALSE------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con colores en los bins para identificar 
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(color ="#ffffff" , 
                 fill = "#EF3C49", 
                 bins=30)+
  stat_bin(aes(label=..count..), 
            geom="text")




## ----warning=FALSE------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con colores en los bins para identificar 
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(color ="#ffffff" , 
                 fill = "#EF3C49", 
                 bins=30)+
  stat_bin(aes(label=..count..), 
           vjust=-0.1, 
           hjust= 0.5,  
           geom="text")




## ----warning=FALSE------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con bins =15
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(color ="#ffffff" , 
                 fill = "#EF3C49", 
                 bins=15)+
  stat_bin(aes(label=..count..), 
           vjust=-0.1, 
           hjust= 0.5,  
           geom="text")


# Gráfico de histograma con bins =15 en el histograma y en el texto
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(color ="#ffffff" , 
                 fill = "#EF3C49", 
                 bins=15)+
  stat_bin(aes(label=..count..), 
           vjust=-0.1, 
           hjust= 0.5,  
           geom="text",
           bins = 15)




## ----warning=FALSE------------------------------------------------------------------------------------------------------------------------------------------------

#calculo de la media y la mediana
media <- mean(datos_pinguinos$flipper_lenght)
media
mediana <- median(datos_pinguinos$flipper_lenght)
mediana




# Gráfico de histograma con colores en los bins para identificar 
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(color ="#ffffff", 
                 fill = "#EF3C49", 
                 bins=30)+
  geom_vline(xintercept = mediana, size = 1) +
  geom_vline(xintercept = media, size = 1, linetype = "dashed", color="blue") 


# Asimétrica, tiene sesgo a la Derecha (cola a la derecha)




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con grafico de densidad
# lwd=1.5 , representa el grosor del borde del
# grafico de densidad
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(y = ..density..), 
                 color ="#ffffff", 
                 fill = "#EF3C49", 
                 bins=30)+
  geom_density(lwd=1.5, colour = "blue") 



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con dos variables
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(fill=sex), 
                 color ="#ffffff", 
                 bins=30)




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma dos variables
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(fill=sex), 
                 color ="#ffffff", 
                 bins=30)+
  stat_bin(aes(label=..count..), 
           vjust=-0.1, 
           hjust= 0.5,  
           geom="text")




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con dos variables
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(fill=sex), 
                 color ="#ffffff", 
                 bins=30,
                 alpha=0.5)




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico de histograma con dos variables
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(fill=sex), 
                 color ="#ffffff", 
                 bins=30,
                 alpha=0.5, 
                 position ="identity")




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_density()



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_density(lwd=1.5,
               color="salmon", 
               fill="lightgreen")



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# dos variable en el color de la lineas
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_density(lwd=1.5, 
               aes(colour = sex))

# dos variable en el color del relleno
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_density(lwd=0.5, 
               aes(fill = sex))


# dos variable linea y relleno del mismo color
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_density(lwd=1.5, 
               aes(color=sex,
                   fill = sex))




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# dos variable en el color de la lineas
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_density(lwd=1.5, 
               alpha=0.35,
               aes(color=sex,
                   fill = sex))




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# Gráfico Ridge son color
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght,
         y=island)) +
   geom_density_ridges()


# Gráfico Ridge  color relleno
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght,
         y=island)) +
   geom_density_ridges(fill="salmon")



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------
# dos variable en el color de la lineas
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght,
         y=island)) +
   geom_density_ridges(aes(fill=island))




## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

# colores con paleta de colores 1
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght,
         y=island)) +
   geom_density_ridges(aes(fill=island))+
  scale_fill_brewer(palette = "Blues")


# colores con paleta de colores 2
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght,
         y=island)) +
   geom_density_ridges(aes(fill=island))+
  scale_fill_brewer(palette = "Pastel2")



# colores con paleta de colores 8
datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght,
         y=island,
         fill=island)) +
   geom_density_ridges()+
  scale_fill_brewer(palette = "Spectral")



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(fill=sex), 
                 color ="#ffffff", 
                 bins=30, 
                 position ="identity")+
  facet_grid(.~sex)



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(fill=sex), 
                 color ="#ffffff", 
                 bins=30, 
                 position ="identity")+
  facet_grid(sex~.)



## -----------------------------------------------------------------------------------------------------------------------------------------------------------------

datos_pinguinos |> 
  ggplot(aes(x= flipper_lenght)) +
  geom_histogram(aes(fill=sex), 
                 color ="#ffffff", 
                 bins=30, 
                 position ="identity")+
  facet_grid(sex~.)+
  labs(title = "Distribución de las longuitud de la aleta de los pinguinos por sexo",
       subtitle = "Datos de las islas...",
       x="Lonuitud",
       y="Cantidad",
       fill="Sexo")



## ----echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------

inec <- read.csv("data/INEC-morbilidad-2023-10-14.csv")
inec <- as_tibble(inec)

# filtrar datos
inec_0 <- inec  |> 
          filter(Region=="PANAMA METRO") 

inec_0$Genero <- as.factor(inec_0$Genero)

inec_0 |> 
  filter(Casos>20) |> 
  ggplot(aes(x= Casos)) +
  geom_histogram(aes(fill=Genero), 
                 color ="#ffffff", 
                 bins=30)+
  facet_grid(Genero~.)+
  labs(title = "Distribución de casos de la Región de Panama Metro",
       subtitle = "Datos INEC")




